@@ -2,9 +2,12 @@ package Lingua::KO::Munja;
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw/roman2hangul hangul2roman/;
+%EXPORT_TAGS = (
+    all => \@EXPORT_OK,
+);
 use warnings;
 use strict;
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 use Convert::Moji 'make_regex';
 
 my $verbose;
@@ -25,8 +28,6 @@ my @initial = qw(
 
 my $initial_re = makearegex (@initial);
 
-print "@initial\n";
-
 my %initial = a2h (@initial);
 
 my @peak = qw(
